/*  This file is part of the OpenGPI library
 *
 *  Copyright (C) 2009, 2010 Jonas Fietz, Mathias J. Krause, Martin Wlotzka
 *  Address: Wilhelm-Maybach-Str. 24, 68766 Hockenheim, Germany
 *  E-mail: info@opengpi.org 
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/**
 * The FinalPage contains a text line and a browse button. The user can specify the directory and file name for saving the parameters
 * by either typing them directly into the text line, or he can browse the file system using the browse button. The FinalPage checks the 
 * user input automatically. The finish button of the OpenGPIWizard is only activated, if a valid directory is specified.
 */


#ifndef FINALPAGE
#define FINALPAGE

#include <QtGui>

class FinalPage : public QWizardPage
{
	Q_OBJECT

public:

	/**
	 * Constructs a FinalPage with a text line, a browse button and some explaining text.
	 * \param parent The parent Widget.
	 */
	FinalPage(QWidget *parent);

	/**
	 * The destructor.
	 */
	~FinalPage();

	QString getText(); /**< Returns the text of the text line.*/

public slots:

	void checkOutFileName(); /**< Checks the text in the text line. If it represents a valid directory, the signal outFileNameIsOK(true)
								   is emitted, otherwise the signal outFileNameIsOK(false) is emitted.*/

signals:

	void outFileNameIsOK(bool); /**< This signal is emitted whenever the text in the text line changes (by user or by program).
								  It passes true, if the text represents a valid directory, otherwise it passes false.*/

private:

	QLabel *subtitle, *text2;
	QLineEdit *line;
	QPushButton *button;
	QGridLayout *layout;

private slots:

	void getOutFileName();
};

#endif
