/*  This file is part of the OpenGPI library
 *
 *  Copyright (C) 2009, 2010 Jonas Fietz, Mathias J. Krause, Martin Wlotzka
 *  Address: Wilhelm-Maybach-Str. 24, 68766 Hockenheim, Germany
 *  E-mail: info@opengpi.org 
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "keyinput.h"

KeyInput::KeyInput(QWidget *parent, QVariant data, QModelIndex index)
: QWidget(parent)
{
	myIndex = index;
	setMouseTracking(true);

	if(data.type() != QVariant::Map) return;

	map = data.toMap();

	setFixedSize(400,70);

	box = new QGroupBox(this);
	box->setAutoFillBackground(true);
	box->setGeometry(10,10,380,50);
	box->setTitle(map.value("displayname","no name defined").toString());
	box->setMouseTracking(true);
	QMap<QString, QVariant> currentlist;
	myInfo = map.value("info","No Info available for this Key.").toString();
	t = map.value("type").toInt();

	QPalette p = palette();

	switch(t)
	{
	case 0:
		lineEdit = new QLineEdit(this);
		lineEdit->setGeometry(150,30,200,20);
		lineEdit->setText(map.value("value").toString());
		lineEdit->setMouseTracking(true);
		connect(lineEdit,SIGNAL(textChanged(QString)),this,SLOT(changeValue(QString)));
		break;

	case 1:
		comboBox = new QComboBox(this);
		comboBox->setGeometry(200,30,150,20);
		comboBox->setMouseTracking(true);
		currentlist = map.value("currentlist").toMap();

		if(!map.value("currentlist").toMap().contains(map.value("value").toString())) {
			p.setColor(QPalette::Window, QColor(Qt::red).lighter(120));
		}

		for(QMap<QString, QVariant>::const_iterator i =
				currentlist.constBegin(); i != currentlist.constEnd(); i++) {
			comboBox->addItem(i.value().toString(), i.key());
			if(map.value("value") == i.key()) {
				comboBox->setCurrentIndex(comboBox->findText(i.value().toString()));
			}
		}
		connect(comboBox,SIGNAL(currentIndexChanged(QString)),this,SLOT(changeValue(QString)));
		break;

	case 2:
		spinBox = new QSpinBox(this);
		spinBox->setGeometry(250,30,100,20);
		if(map.value("min").toInt() > map.value("value").toInt() ||
				map.value("max").toInt() < map.value("value").toInt()) {
			p.setColor(QPalette::Window, QColor(Qt::red).lighter(120));
		}
		spinBox->setRange(map.value("min").toInt(),map.value("max").toInt());
		spinBox->setValue(map.value("value").toInt());
		spinBox->setMouseTracking(true);
		connect(spinBox,SIGNAL(valueChanged(int)),this,SLOT(changeValue(int)));
		break;

	case 3:
		lineEdit = new QLineEdit(this);
		lineEdit->setGeometry(100,30,190,20);
		browseButton = new QPushButton("Browse...",this);
		browseButton->setGeometry(300,25,80,25);
		lineEdit->setText(map.value("value").toString());
		lineEdit->setMouseTracking(true);
		connect(browseButton,SIGNAL(clicked()),this,SLOT(browseButtonClicked()));
		connect(lineEdit,SIGNAL(textChanged(QString)),this,SLOT(changeValue(QString)));
		break;

	default:
		break;
	}
	box->setPalette(p);
	setEnabled(map.value("enabled","true").toBool());
}

KeyInput::KeyInput(QWidget *parent)
: QWidget(parent)
{
	setFixedSize(400,70);

	box = new QGroupBox(this);
	box->setGeometry(10,10,380,50);
}

KeyInput::~KeyInput(){}

QVariant KeyInput::value()
{
	QMap<QString, QVariant> currentlist;

	switch(t)
	{
	case 0:
		return lineEdit->text();
		break;

	case 1:
		currentlist = map.value("currentlist").toMap();
		for(QMap<QString, QVariant>::const_iterator i =
				currentlist.constBegin(); i != currentlist.constEnd(); i++) {
			if(comboBox->currentText() == i.value().toString()) {
				return i.key();
			}
		}
		break;

	case 2:
		return spinBox->value();
		break;

	case 3:
		return lineEdit->text();
		break;

	default:
		break;
	}
	return QVariant();
}

QModelIndex KeyInput::index()
{
	return myIndex;
}

void KeyInput::changeData(QVariant v)
{
	QMap<QString, QVariant> currentlist;

	QPalette p = palette();

	if(v.type() == QVariant::Map)
	{
		QMap<QString,QVariant> map = v.toMap();
		this->map = map;

		switch(t)
		{
		case 0:
			disconnect(lineEdit,SIGNAL(textChanged(QString)),0,0);
			lineEdit->setText(map.value("value").toString());
			connect(lineEdit,SIGNAL(textChanged(QString)),this,SLOT(changeValue(QString)));
			break;

		case 1:
			disconnect(comboBox,SIGNAL(currentIndexChanged(QString)),0,0);
			comboBox->clear();
			comboBox->setCurrentIndex(0);
			if(!map.value("currentlist").toMap().contains(map.value("value").toString())) {
				p.setColor(QPalette::Window, QColor(Qt::red).lighter(120));
			}
			currentlist = map.value("currentlist").toMap();
			for(QMap<QString, QVariant>::const_iterator i =
					currentlist.constBegin(); i != currentlist.constEnd(); i++) {
				comboBox->addItem(i.value().toString(), i.key());
				if(map.value("value") == i.key()) {
					comboBox->setCurrentIndex(comboBox->findText(i.value().toString()));
				}
			}
			connect(comboBox,SIGNAL(currentIndexChanged(QString)),this,SLOT(changeValue(QString)));
			break;

		case 2:
			disconnect(spinBox,SIGNAL(valueChanged(int)),0,0);
			qDebug() << "changeData: min: " << map.value("min").toInt() << " value: " << map.value("value").toInt();
			if(map.value("min").toInt() > map.value("value").toInt() || 
					map.value("max").toInt() < map.value("value").toInt()) {
				p.setColor(QPalette::Window, QColor(Qt::red).lighter(120));
			}
			spinBox->setRange(map.value("min").toInt(),map.value("max").toInt());
			spinBox->setValue(map.value("value").toInt());
			connect(spinBox,SIGNAL(valueChanged(int)),this,SLOT(changeValue(int)));
			break;

		case 3:
			disconnect(lineEdit,SIGNAL(textChanged(QString)),0,0);
			lineEdit->setText(map.value("value").toString());
			connect(lineEdit,SIGNAL(textChanged(QString)),this,SLOT(changeValue(QString)));
			break;

		default:
			break;
		}
		if(map.value("enabled","true").toBool())
		{
			setEnabled(true);
		}
		else
		{
			setEnabled(false);
		}
	}
	else
	{
		switch(t)
		{
		case 0:
			lineEdit->setText(v.toString());
			break;

		case 1:
			currentlist = map.value("currentlist").toMap();
			comboBox->setCurrentIndex(comboBox->findText(currentlist.value(v.toString()).toString()));
			break;

		case 2:
			spinBox->setValue(v.toInt());
			break;

		default:
			break;
		}
	}
	box->setPalette(p);
}

void KeyInput::mouseMoveEvent(QMouseEvent * event)
{
	int x = event->x();
	int y = event->y();
	if(5<=x && x<=395 && 5<=y && y<=65) {
		if( (map.contains("min") && map.value("min").toInt() > map.value("value").toInt()) ||
			(map.contains("max") && map.value("max").toInt() < map.value("value").toInt()) ||
			( map.contains("currentlist") && ! map.value("currentlist").toMap().contains(map.value("value").toString() ) )) {
			emit showMyInfo(box->title(), myInfo + " The current value of this "
					"key is " +	map.value("value").toString() + 
					"This is not an allowed value.");

			} else 		emit showMyInfo(box->title(),myInfo);
	}
}

void KeyInput::browseButtonClicked()
{
	lineEdit->setText(QFileDialog::getOpenFileName(this, tr("Directory...")));
}

void KeyInput::changeValue(QString s)
{
	QMap<QString, QVariant> currentlist = map.value("currentlist").toMap();;
	QVariant v;
	v = s;
	if(t == 1) { // combobox
		for(QMap<QString, QVariant>::const_iterator i = currentlist.constBegin(); 
				i != currentlist.constEnd(); i++) 
		{
			if(s == i.value().toString()) {
				v = i.key();
				break;
			}
		}
	}

	emit valueChanged(v,myIndex);
}

void KeyInput::changeValue(int i)
{
	QVariant v;
	v = i;
	emit valueChanged(v,myIndex);
}
