/*  This file is part of the OpenGPI library
 *
 *  Copyright (C) 2009, 2010 Jonas Fietz, Mathias J. Krause, Martin Wlotzka
 *  Address: Wilhelm-Maybach-Str. 24, 68766 Hockenheim, Germany
 *  E-mail: info@opengpi.org 
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "keypage.h"

KeyPage::KeyPage(QWidget *parent)
: QWizardPage(parent)
{
	scrollArea = new QScrollArea(this);
	widget = new QWidget(this);
	scrollArea->setWidget(widget);
	infoBox = new QLabel("Tips...",this);
	infoBox->setTextFormat(Qt::RichText);
	infoBox->setWordWrap(true);
	infoBox->setFixedHeight(100);
	infoBox->setFrameStyle(QFrame::StyledPanel | QFrame::Sunken);
	infoBox->setAlignment(Qt::AlignTop);
	layout = new QVBoxLayout();
	layout->addWidget(scrollArea);
	layout->addWidget(infoBox);
	setLayout(layout);
}

KeyPage::~KeyPage(){}

void KeyPage::setKeys(QList<QVariant> data,QList<QModelIndex> index)
{
	while(!key.isEmpty()) delete key.takeFirst();

	setTitle(data.value(0).toString());
	int count = data.count();
	widget->resize(400,(count-1)*70);
	for(int i = 1; i < count; i++)
	{
		key.append(new KeyInput(widget, data.value(i), index.value(i)));
key.value(i-1)->setGeometry(0,(i-1)*70,400,70);
	key.value(i-1)->show();
		connect(key.value(i-1),SIGNAL(valueChanged(QVariant,QModelIndex)),this,SIGNAL(valueChanged(QVariant,QModelIndex)));
		connect(key.value(i-1),SIGNAL(showMyInfo(QString,QString)),this,SLOT(setInfo(QString,QString)));
	}
}

void KeyPage::changeData(QModelIndex i, QVariant v)
{
	for(int j = 0; j < key.count(); j++)
		if(key.value(j)->index() == i)
			key.value(j)->changeData(v);
}

void KeyPage::setInfo(QString name,QString info)
{
	QString s = "<body bgcolor='#FBB117'><h3>";
	s += name;
	s += "</h3>\n";
	s += "<h6>";
	s += info;
	s += "</h6></body>";

	infoBox->setText(s);
}

void KeyPage::setInfo(QString warning)
{
	QString s = "<h3>Warning!</h3>\n";
	s += warning;
	infoBox->setText(s);
}

void KeyPage::clear()
{
	setTitle("Currently no Keys to display...");
	while(!key.isEmpty()) delete key.takeFirst();
	widget->resize(10,10);
}
