/*  This file is part of the OpenGPI library
 *
 *  Copyright (C) 2009, 2010 Jonas Fietz, Mathias J. Krause, Martin Wlotzka
 *  Address: Wilhelm-Maybach-Str. 24, 68766 Hockenheim, Germany
 *  E-mail: info@opengpi.org 
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/** The KeyPage class holds several KeyInput objects and an InfoBox and presents them in a vertical layout.
 * It provides scrollbars, if not all of the KeyInput objects can be displayed at once.
 */


#ifndef KEYPAGE
#define KEYPAGE

#include "keyinput.h"

class KeyPage : public QWizardPage
{
	Q_OBJECT

public:

	/**
	 * Constructs an empty KeyPage which only contains the InfoBox.
	 * \param parent The parent widget.
	 */
	KeyPage(QWidget *parent);

	/**
	 * The destructor.
	 */
	~KeyPage();

	/**
	 * Constructs the KeyInput objects and displays them.
	 * \param data A list of data to initialize the KeyInput objects.
	 * \param index A list of indexes corresponding to the keys.
	 */
	void setKeys(QList<QVariant> data,QList<QModelIndex> index);

	/**
	 * Changes the data in the KeyInput object corresponding to the key with index i.
	 * \param i Index of the affected key.
	 * \param v New data to be set.
	 */
	void changeData(QModelIndex i, QVariant v);

	void clear(); /**< Deletes all KeyInput objects.*/

public slots:

	/**
	 * This slot is used to present help information in the InfoBox.
	 * \param name This string is set as the title in the InfoBox.
	 * \param info The info text.
	 */
	void setInfo(QString name, QString info);

	/**
	 * This slot is used to present warnings in the InfoBox.
	 * \param warning The warning text.
	 */
	void setInfo(QString warning);

signals:

	void valueChanged(QVariant,QModelIndex); /**< This signal is emitted, when the value in a KeyInput object has changed.
	 * It passes the new value as first argument, and the index corresponding
					      * to the key as second argument.*/

private:

	QScrollArea *scrollArea;
	QWidget *widget;
	QList<KeyInput*> key;
	QVBoxLayout *layout;
	QLabel *infoBox;
};

#endif
