/*  This file is part of the OpenGPI library
 *
 *  Copyright (C) 2009, 2010 Jonas Fietz, Mathias J. Krause, Martin Wlotzka
 *  Address: Wilhelm-Maybach-Str. 24, 68766 Hockenheim, Germany
 *  E-mail: info@opengpi.org 
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "loadpage.h"

LoadPage::LoadPage(QWidget *parent)
: QWizardPage(parent)
{
	setTitle("Parameter Description File");
	text1 = new QLabel("Specify the directory of the Parameter Description File.");
	line = new QLineEdit();
	line->resize(200,30);
	button = new QPushButton("Browse...");
	button->resize(50,30);
	text2 = new QLabel("Click \"Next\" to load the Parameter Description File.");

	layout = new QGridLayout();
	layout->addWidget(text1,0,0,1,2);
	layout->addWidget(line,1,0,1,1);
	layout->addWidget(button,1,1,1,1);
	layout->addWidget(text2,2,0,1,2);
	setLayout(layout);

	connect(button,SIGNAL(clicked()),this,SLOT(getInFileName()));
	connect(line,SIGNAL(textChanged(QString)),this,SLOT(checkInFileName()));
}

LoadPage::~LoadPage(){}

QString LoadPage::currentText()
{
	return line->text();
}

void LoadPage::setText(QString text)
{
	line->setText(text); 
}

void LoadPage::getInFileName()
{
	QFileDialog openDialog(this, tr("Load Parameter Description"),"./",tr("XML files (*.xml)"));
	openDialog.setFileMode(QFileDialog::ExistingFile);
	openDialog.setViewMode(QFileDialog::Detail);
	if(openDialog.exec())
		line->setText(openDialog.selectedFiles().at(0));
}

void LoadPage::checkInFileName()
{
	QString s = line->text();
	if(s.contains(".xml"))
		emit inFileNameIsOK(QDir().exists(s));
	else emit inFileNameIsOK(false);
}
