/*  This file is part of the OpenGPI library
 *
 *  Copyright (C) 2009, 2010 Jonas Fietz, Mathias J. Krause, Martin Wlotzka
 *  Address: Wilhelm-Maybach-Str. 24, 68766 Hockenheim, Germany
 *  E-mail: info@opengpi.org 
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/**
 * The LoadPage class is used to get the file name and directory of description files or saved parameter files to be loaded.
 * It presents a text line and a browse button. The user can type the file name into the text line or use the button to browse through
 * the directories. The directory and file name in the text line are automatically checked for existence.
 */


#ifndef LOADPAGE
#define LOADPAGE

#include <QtGui>

class LoadPage : public QWizardPage
{
	Q_OBJECT

public:

	/**
	 * Constructs a LoadPage with text line and browse button.
	 * \param parent The parent widget.
	 */
	LoadPage(QWidget *parent);

	/**
	 * The destructor.
	 */
	~LoadPage();

	QString currentText(); /**< Returns the current text of the text line.*/
	void setText(QString text); /**< Sets the text in the text line.*/

public slots:

	void checkInFileName(); /**< Validates the text in the text line. If the text is representing a valid directory,
			    the signal inFileNameIsOK(true) is emitted, otherwise inFileNameIsOK(false) is emitted.*/

signals:

	void inFileNameIsOK(bool); /**< This signal is emitted, if the directory and file name in the text line exist.*/

private:

	QLabel *text1, *text2;
	QLineEdit *line;
	QPushButton *button;
	QGridLayout *layout;

private slots:

	void getInFileName();
};

#endif
