/*  This file is part of the OpenGPI library
 *
 *  Copyright (C) 2009, 2010 Jonas Fietz, Mathias J. Krause, Martin Wlotzka
 *  Address: Wilhelm-Maybach-Str. 24, 68766 Hockenheim, Germany
 *  E-mail: info@opengpi.org 
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "opengpi.h"

OpenGPI::OpenGPI()
: QWidget()
{
	Gui = new OpenGPIGUI(this,0);

	Data = new ParamData(this);

	Export = new XMLParamExport(this);

	Import = new XMLParamImport(this);

	connect(Gui,SIGNAL(sendDescriptionFileName(QString)),Import,SLOT(importDescription(QString)));
	connect(Import,SIGNAL(sendDescriptionDoc(QDomDocument)),Data,SLOT(receiveDescriptionDoc(QDomDocument)));

	connect(Gui,SIGNAL(sendParamFileName(QString)),Import,SLOT(importParam(QString)));
	connect(Import,SIGNAL(sendParamDoc(QDomDocument)),Data,SLOT(receiveParamDoc(QDomDocument)));

	connect(Data,SIGNAL(sendModel(QAbstractItemModel*)),Gui,SLOT(receiveModel(QAbstractItemModel*)));
	connect(Gui,SIGNAL(checkAllBlocks()),Data,SIGNAL(checkAllBlocks()));

	connect(Gui,SIGNAL(getFirstKeys()),Data,SLOT(collectFirstKeys()));

	connect(Gui,SIGNAL(getNextKeys(QModelIndex)),Data,SLOT(collectNextKeys(QModelIndex)));
	connect(Data,SIGNAL(sendNextKeys(QList<QVariant>,QList<QModelIndex>)),Gui,SLOT(receiveNextKeys(QList<QVariant>,QList<QModelIndex>)));

	connect(Gui,SIGNAL(getPreviousKeys(QModelIndex)),Data,SLOT(collectPreviousKeys(QModelIndex)));
	connect(Data,SIGNAL(sendPreviousKeys(QList<QVariant>,QList<QModelIndex>)),Gui,SLOT(receivePreviousKeys(QList<QVariant>,QList<QModelIndex>)));

	connect(Gui,SIGNAL(getKeys(QModelIndex)),Data,SLOT(collectKeys(QModelIndex)));
	connect(Data,SIGNAL(sendKeys(QList<QVariant>,QList<QModelIndex>)),Gui,SLOT(receiveKeys(QList<QVariant>,QList<QModelIndex>)));

	connect(Gui,SIGNAL(valueChanged(QVariant,QModelIndex)),Data,SLOT(changeValue(QVariant,QModelIndex)));
	connect(Data,SIGNAL(dataChanged(QModelIndex,QVariant)),Gui,SIGNAL(dataChanged(QModelIndex,QVariant)));

	connect(Gui,SIGNAL(sendOutFileName(QString)),Data,SLOT(prepareExport(QString)));
	connect(Data,SIGNAL(sendExportData(QDomDocument,QString)),Export,SLOT(exportData(QDomDocument,QString)));

	connect(Gui,SIGNAL(getCurrentSettings()),Data,SLOT(getCurrentSettings()));
	connect(Data,SIGNAL(sendCurrentSettings(QTreeWidgetItem*)),Gui,SIGNAL(sendCurrentSettings(QTreeWidgetItem*)));

	connect(Data,SIGNAL(showInfo(QString)),Gui,SIGNAL(showInfo(QString)));
}

OpenGPI::~OpenGPI(){}

void OpenGPI::showGUI()
{
	Gui->show();
}
