/*  This file is part of the OpenGPI library
 *
 *  Copyright (C) 2009, 2010 Jonas Fietz, Mathias J. Krause, Martin Wlotzka
 *  Address: Wilhelm-Maybach-Str. 24, 68766 Hockenheim, Germany
 *  E-mail: info@opengpi.org 
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/**
 * The OpenGPI class contains the four modules of OpenGPI: The OpenGPIGUI, the ParamData, the XMLParamImport and the XMLParamExport.
 * It connects the signals and slots of the modules they are using to communicate with each other.
 */


#ifndef OPENGPI_H
#define OPENGPI_H

#include <QtGui>

#include "opengpigui.h"
#include "paramdata.h"
#include "xmlparamexport.h"
#include "xmlparamimport.h"


class OpenGPI: public QWidget
{
	Q_OBJECT

public:

	/**
	 * Constructs the modules and connects their signals and slots.
	 */
	OpenGPI();

	/**
	 * The destructor.
	 */
	~OpenGPI();

	void showGUI(); /**< Makes the OpenGPIGUI visible.*/

private:

	OpenGPIGUI *Gui;
	ParamData *Data;
	XMLParamExport *Export;
	XMLParamImport *Import;
};

#endif
