/*  This file is part of the OpenGPI library
 *
 *  Copyright (C) 2009, 2010 Jonas Fietz, Mathias J. Krause, Martin Wlotzka
 *  Address: Wilhelm-Maybach-Str. 24, 68766 Hockenheim, Germany
 *  E-mail: info@opengpi.org 
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "paramdata.h"

ParamData::ParamData(QWidget *parent)
: QWidget(parent)
{
	Model = new TreeModel(this);
	connect(Model,SIGNAL(modelSetupFinished()),this,SLOT(modelSetupFinished()));
	connect(Model,SIGNAL(dataChanged(QModelIndex,QVariant)),this,SIGNAL(dataChanged(QModelIndex,QVariant)));
	connect(Model,SIGNAL(showInfo(QString)),this,SIGNAL(showInfo(QString)));
	connect(this,SIGNAL(checkAllBlocks()),Model,SLOT(checkAllBlocks()));
}

ParamData::~ParamData()
{
	delete Model;
}

void ParamData::receiveDescriptionDoc(QDomDocument InDoc)
{
	Model->deleteAll();
	Model->setupModelData(InDoc);
}

void ParamData::receiveParamDoc(QDomDocument doc)
{
	Model->setParam(doc);
}

void ParamData::modelSetupFinished()
{
	emit sendModel(Model);
}

void ParamData::collectFirstKeys()
{
	QModelIndex in = Model->firstIndex();
	QList<QVariant> dataList;
	QList<QModelIndex> indexList;
	dataList = Model->keyDataList(in);
	indexList = Model->keyIndexList(in);
	emit sendNextKeys(dataList,indexList);
}

void ParamData::collectNextKeys(QModelIndex i)
{
	QModelIndex in = Model->nextEnabledIndex(i);
	QList<QVariant> dataList;
	QList<QModelIndex> indexList;
	dataList = Model->keyDataList(in);
	indexList = Model->keyIndexList(in);
	emit sendNextKeys(dataList,indexList);
}

void ParamData::collectPreviousKeys(QModelIndex i)
{
	QModelIndex in = Model->previousEnabledIndex(i);
	QList<QVariant> dataList;
	QList<QModelIndex> indexList;
	dataList = Model->keyDataList(in);
	indexList = Model->keyIndexList(in);
	emit sendPreviousKeys(dataList,indexList);
}

void ParamData::collectKeys(QModelIndex index)
{
	QList<QVariant> dataList;
	QList<QModelIndex> indexList;
	dataList = Model->keyDataList(index);
	indexList = Model->keyIndexList(index);
	emit sendKeys(dataList,indexList);
}

void ParamData::changeValue(QVariant v,QModelIndex index)
{
	Model->setData(index,v,Qt::UserRole);
}

void ParamData::getKeyDataUpdate(QModelIndex i)
{
	QVariant v = Model->data(i,Qt::DisplayRole);
}

void ParamData::prepareExport(QString outfilename)
{
	QDomDocument d = Model->setupOutDoc();
	emit sendExportData(d,outfilename);
}

void ParamData::getCurrentSettings()
{
	QTreeWidgetItem* tree = Model->currentSettings();
	emit sendCurrentSettings(tree);
}
