/*  This file is part of the OpenGPI library
 *
 *  Copyright (C) 2009, 2010 Jonas Fietz, Mathias J. Krause, Martin Wlotzka
 *  Address: Wilhelm-Maybach-Str. 24, 68766 Hockenheim, Germany
 *  E-mail: info@opengpi.org 
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/**
 * The StartPage is used to present user information about how to use the OpenGPIGUI. The first wizard page
 * shown at startup is an object of the StartPage class.
 */

#ifndef STARTPAGE
#define STARTPAGE

#include <QtGui>

class StartPage : public QWizardPage
{
	Q_OBJECT

public:

	/**
	 * Constructs a StartPage with default text messages.
	 * \param parent The parent widget.
	 */
	StartPage(QWidget *parent);

	/**
	 * Constructs a StartPage with user defined text messages.
	 * \param parent The parent widget.
	 * \param text1 The first text presented below the title and the subtitle.
	 * \param text2 The second text presented below the title and the subtitle.
	 */
	StartPage(QWidget *parent, QString text1, QString text2);

	/**
	 * The destructor.
	 */
	~StartPage();

private:

	QLabel *t1, *t2;
	QVBoxLayout *layout;
};

#endif
