/*  This file is part of the OpenGPI library
 *
 *  Copyright (C) 2009, 2010 Jonas Fietz, Mathias J. Krause, Martin Wlotzka
 *  Address: Wilhelm-Maybach-Str. 24, 68766 Hockenheim, Germany
 *  E-mail: info@opengpi.org 
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/**
 * The TreeItem class is used for storing the actual configuration data and is
 * a node in the TreeModel class.
 */
#ifndef TREEITEM_H
#define TREEITEM_H

#include <QList>
#include <QVariant>

class TreeModel;

class TreeItem
{
private:
	friend class TreeModel;

	void appendChild(TreeItem *child);

	TreeItem *child(int row);
	int childCount() const;
	int columnCount() const;
	QVariant data(int column) const;
	int row() const;
	int rowCount();
	TreeItem *parent();

	QList<TreeItem*> childItems;
	QList<QVariant> itemData;
	TreeItem *parentItem;


public:
	/**
	 * Initializes the parent and itemdata.
	 */
	TreeItem(const QList<QVariant> &data, TreeItem *parent = 0);

	/** 
	 * Destructor: Cleans up the childItems.
	 */
	~TreeItem();

};

#endif
